@@ -1,17 +1,17 @@
 # Define api parse function
 parse_resp <- function(resp) {
-
   if (httr::http_type(resp) != "application/json") {
     stop("API did not return json",
-         call. = FALSE)
+      call. = FALSE
+    )
   }
 
   if (httr::http_error(resp) == TRUE) {
     stop("The request failed")
   } else {
     parsed_content <- jsonlite::fromJSON(httr::content(resp,
-                                                       as = "text",
-                                                       encoding = "UTF-8"
+      as = "text",
+      encoding = "UTF-8"
     ),
     flatten = TRUE
     )
@@ -20,5 +20,4 @@ parse_resp <- function(resp) {
 
     return(tibbled_content)
   }
-
 }
